@@ -17,7 +17,7 @@ from threading import Timer
 
 from firex_flame.main_app import start_flame
 from firex_flame.flame_helper import get_flame_debug_dir, get_flame_pid_file_path, DEFAULT_FLAME_TIMEOUT, \
-    BrokerConsumerConfig
+    BrokerConsumerConfig, get_flame_url
 
 logger = logging.getLogger(__name__)
 
@@ -28,6 +28,7 @@ def _parse_args():
     parser.add_argument('--uid', help='Unique identifier for the represented FireX run.')
     parser.add_argument('--logs_dir', help='Logs directory.', default=None, required=True)
     parser.add_argument('--chain', help='Chain of the run.', default=None)
+    # TODO: could validate either rec file exists or broker URL is legible from logs_dir is supplied.
     parser.add_argument('--recording', help='A file containing the recording of celery events.', default=None)
     parser.add_argument('--central_server', help='A central web server from which the UI and logs can be served.',
                         default=None)
@@ -40,8 +41,6 @@ def _parse_args():
                         default='http://www.firexapp.com/')
     parser.add_argument('--firex_bin_path', help='Path to a firex executable.',
                         default=None)
-    # TODO: could validate either rec file exists or broker is supplied.
-    parser.add_argument('--broker', help='Celery broker.', default=None)
     parser.add_argument('--flame_timeout', help='Maximum lifetime of this service, in seconds', type=int,
                         default=DEFAULT_FLAME_TIMEOUT)
     parser.add_argument('--broker_recv_ready_file', help='File to create immediately before capturing celery events.',
@@ -66,12 +65,14 @@ def _parse_args():
     return parser.parse_args()
 
 
-class ShutdownSignalHandler:
+class ShutdownHandler:
 
     def __init__(self):
         self.web_server = None
         signal.signal(signal.SIGTERM, self.sigterm_handler)
         signal.signal(signal.SIGINT, self.sigint_handler)
+        signal.signal(signal.SIGHUP,
+                      lambda _, __: logger.warning("Ignoring SIGHUP signal -- will timeout with broker."))
 
     def sigterm_handler(self, _, __):
         self.shutdown('SIGTERM detected')
@@ -85,8 +86,10 @@ class ShutdownSignalHandler:
     def shutdown(self, reason):
         logging.info("Stopping entire Flame Server for reason: %s" % reason)
         # TODO: shutdowns that occur while the broker is still receiving events will not have the data model dumped,
-        # since that's currently exclusively the responsibility of the broker processor. This shutdown method
-        # should do a 'dump complete if not already dumped' and handle concurrency issues.
+        #  since that's currently exclusively the responsibility of the broker processor. This shutdown method
+        #  should do a 'dump complete if not already dumped' and handle concurrency issues, but only when a broker
+        #  is present (i.e. not when replaying a recording). Generating the dumped model while processing events
+        #  mitigates but does not eliminate this issue.
         logging.shutdown()
         if self.web_server:
             self.web_server.stop()
@@ -128,8 +131,7 @@ def _create_run_metadata(cli_args):
 
 
 def create_broker_processor_config(args):
-    return BrokerConsumerConfig(args.broker,
-                                args.broker_max_retry_attempts,
+    return BrokerConsumerConfig(args.broker_max_retry_attempts,
                                 args.broker_recv_ready_file,
                                 args.terminate_on_complete)
 
@@ -143,7 +145,7 @@ class NoopTimer:
 
 
 def main():
-    shutdown_handler = ShutdownSignalHandler()
+    shutdown_handler = ShutdownHandler()
 
     args = _parse_args()
     _config_logging(args.logs_dir)
@@ -156,12 +158,13 @@ def main():
                                  args.extra_task_dump_paths.split(',') if args.extra_task_dump_paths else [])
         # Allow the shutdown handler to stop the web server before we serve_forever.
         shutdown_handler.web_server = web_server
+        print(f"Flame server running on: {get_flame_url(web_server.server_port)}")
         web_server.serve_forever()
-        t.cancel()
     except Exception as e:
         logger.exception(e)
         shutdown_handler.shutdown(str(e))
     finally:
+        t.cancel()
         logger.info("Flame server finished.")
 
 
